OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "La version {version} est disponible. Cliquez ici pour plus d'informations sur comment mettre à jour.",
    "Channel updated" : "Canal de mise à jour modifié",
    "Web updater is disabled" : "La mise à jour par l'interface Web est désactivée ",
    "Update notifications" : "Notifications de mises à jour",
    "The update server could not be reached since %d days to check for new updates." : "Le serveur de mise à jour n'a pas pu être atteint depuis %d jours pour vérifier les nouvelles mises à jour.",
    "Please check the Nextcloud and server log files for errors." : "Veuillez vérifier les fichiers de log de Nextcloud et du serveur pour les erreurs.",
    "Update to %1$s is available." : "Une mise à jour vers %1$s est disponible",
    "Update to {serverAndVersion} is available." : "La mise à jour de {serverAndVersion} est disponible",
    "Update for {app} to version %s is available." : "Une mise à jour de {app} vers la version %s est disponible.",
    "Update notification" : "Notification mise à jour",
    "Displays update notifications for Nextcloud and provides the SSO for the updater." : "Affiche les notifications de mise à jour pour Nextcloud et fournit l'authentification unique SSO pour le programme de mise à jour.",
    "Update" : "Mise à jour",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "La version que vous utilisez n'est plus maintenue. Assurez vous d'effectuer une mise à jour vers une version prise en charge dès que possible.",
    "Apps missing compatible version" : "Applications n'ayant pas de version compatible",
    "View in store" : "Afficher dans le magasin d'applications",
    "Apps with compatible version" : "Applications compatibles avec la nouvelle version",
    "Please note that the web updater is not recommended with more than 100 accounts! Please use the command line updater instead!" : "Veuillez noter que la mise à jour par le navigateur n'est pas recommandée si votre instance comporte plus de 100 comptes ! Veuillez utiliser l'interface en ligne de commandes. ",
    "Open updater" : "Ouvrir l'interface de mise à jour",
    "Download now" : "Télécharger maintenant",
    "Web updater is disabled. Please use the command line updater or the appropriate update mechanism for your installation method (e.g. Docker pull) to update." : "La mise à jour par l'interface web est désactivée. Veuillez utiliser la mise à jour par ligne de commande ou le mécanisme de mise à jour approprié pour votre méthode d'installation (par exemple, Docker pull) pour effectuer la mise à jour.",
    "What's new?" : "Quoi de neuf ?",
    "View changelog" : "Voir le journal des modifications",
    "The update check is not yet finished. Please refresh the page." : "La vérification de la mise-à-jour n'est pas encore terminée. Veuillez rafraîchir la page.",
    "Your version is up to date." : "Votre version est à jour.",
    "A non-default update server is in use to be checked for updates:" : "Un serveur spécifique est actuellement configuré pour la vérification des mises-à-jour :",
    "Update channel" : "Canal de mise à jour",
    "Changing the update channel also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Modifier le canal de mise à jour affectera aussi la page de gestion des applications. Par exemple, après avoir choisi le canal bêta, les mises à jour bêta des applications vous seront proposées.",
    "Current update channel:" : "Canal de mise à jour actuel",
    "You can always update to a newer version. But you can never downgrade to a more stable version." : "Vous pouvez à tout moment mettre à jour votre instance Nextcloud vers une version plus récente. Vous ne pourrez cependant jamais revenir à une version antérieure en sélectionnant un canal plus stable.",
    "Notify members of the following groups about available updates:" : "Notifier les membres des groupes suivants des mises à jours disponibles :",
    "No groups" : "Aucun groupe",
    "Only notifications for app updates are available." : "Seules les notifications de mises à jour d'applications sont disponibles. ",
    "The selected update channel makes dedicated notifications for the server obsolete." : "Le canal de mise à jour sélectionné rend obsolètes les notifications dédiées au serveur.",
    "The selected update channel does not support updates of the server." : "Le canal de mises à jour sélectionné ne supporte pas les mises à jour du serveur.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Une nouvelle version est disponible : <strong>{newVersionString}</strong>",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Notez qu’après une nouvelle version, la mise à jour n’apparaît qu’après la première version mineure ou ultérieure. Nous déployons de nouvelles versions réparties sur le temps et nous sautons parfois une version lorsque des problèmes sont trouvés. Pour en savoir plus sur les mises à jour et les canaux de diffusion, visitez {link}",
    "Checked on {lastCheckedDate} - Open changelog" : "Vérifié le {lastCheckedDate} - Ouvrir le journal des modifications",
    "Checking apps for compatible versions" : "Vérification de la compatibilité des applications",
    "Please make sure your config.php does not set <samp>appstoreenabled</samp> to false." : "Veuillez vous assurer que le paramètre <samp>appstoreenabled</samp> n'est pas défini à false dans votre config.php.",
    "Could not connect to the App Store or no updates have been returned at all. Search manually for updates or make sure your server has access to the internet and can connect to the App Store." : "Impossible de se connecter au magasin d'applications ou aucune mise à jour n'est disponible. Recherchez manuellement les mises à jour ou assurez-vous que votre serveur a accès à Internet et peut se connecter au magasin d'applications.",
    "<strong>All</strong> apps have a compatible version for this Nextcloud version available." : "<strong>Toutes</strong> les applications ont une version compatible avec cette version de Nextcloud.",
    "Enterprise" : "Entreprise",
    "For enterprise use. Provides always the latest patch level, but will not update to the next major release immediately. That update happens once Nextcloud GmbH has done additional hardening and testing for large-scale and mission-critical deployments. This channel is only available to customers and provides the Nextcloud Enterprise package." : "Pour les entreprises. Fournit toujours le correctif le plus récent, mais ne mettra pas à jour dans la version majeure suivante immédiatement. Cette mise à jour sera effectuée une fois que Nextcloud GmbH aura effectué les renforcements et tests pour permettre un déploiement en production et à grande échelle. Ce canal de mise à jour est seulement disponible pour les clients et fournit le paquet Nextcloud Entreprise.",
    "Stable" : "Stable",
    "The most recent stable version. It is suited for regular use and will always update to the latest major version." : "La version stable la plus récente. Elle est adaptée pour une utilisation régulière et sera toujours mise à jour vers la dernière version majeure.",
    "Beta" : "Beta",
    "A pre-release version only for testing new features, not for production environments." : "Une version préliminaire utilisée seulement pour tester les nouvelles fonctionnalités, n'est pas adaptée dans un environnement de production.",
    "_<strong>%n</strong> app has no compatible version for this Nextcloud version available._::_<strong>%n</strong> apps have no compatible version for this Nextcloud version available._" : ["<strong>%n</strong> application n'a pas de version compatible pour cette version de Nextcloud disponible.","<strong>%n</strong> applications n'ont pas de version compatible pour cette version de Nextcloud disponible.","<strong>%n</strong> applications n'ont pas de version compatible avec cette version de Nextcloud disponible."],
    "Please note that the web updater is not recommended with more than 100 users! Please use the command line updater instead!" : "Veuillez noter que la mise à jour par le navigateur n'est pas recommandée si votre instance comporte plus de 100 utilisateurs ! Veuillez utiliser l'interface en ligne de commandes. ",
    "Please use the command line updater to update." : "Veuillez utiliser le programme de mise à jour en ligne de commande pour mettre à jour. ",
    "You can change the update channel below which also affects the apps management page. E.g. after switching to the beta channel, beta app updates will be offered to you in the apps management page." : "Vous pouvez modifier le canal de distribution ci-dessous mais ceci changera aussi le canal pour les applications. Par exemple, après avoir choisi le canal Beta, les applications en version Beta seront aussi proposées dans les mises à jour.",
    "Update channel:" : "Canal de mise à jour :",
    "Note that after a new release the update only shows up after the first minor release or later. We roll out new versions spread out over time to our users and sometimes skip a version when issues are found. Learn more about updates and release channels at {link}" : "Notez qu’après une nouvelle version, la mise à jour n’apparaît qu’après la première version mineure ou ultérieure. Nous déployons de nouvelles versions réparties sur le temps à nos utilisateurs et nous sautons parfois une version lorsque des problèmes sont trouvés. Pour en savoir plus sur les mises à jour et les canaux de diffusion, visitez {link}",
    "Checked on {lastCheckedDate}" : "Vérifié le {lastCheckedDate}"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
